@@ -3,7 +3,7 @@
 # 
 # source file of the GNU LilyPond music typesetter
 #
-# (c) 1998--2007 Han-Wen Nienhuys <hanwen@xs4all.nl>
+# (c) 1998--2009 Han-Wen Nienhuys <hanwen@xs4all.nl>
 #                 Jan Nieuwenhuizen <janneke@gnu.org>
 
 import __main__
@@ -11,7 +11,6 @@ import glob
 import os
 import re
 import shutil
-import string
 import sys
 import optparse
 
@@ -19,38 +18,45 @@ import optparse
 # Users of python modules should include this snippet
 # and customize variables below.
 
-# We'll suffer this path init stuff as long as we don't install our
-# python packages in <prefix>/lib/pythonx.y (and don't kludge around
-# it as we do with teTeX on Red Hat Linux: set some environment var
-# (PYTHONPATH) in profile)
-
-# If set, LILYPOND_DATADIR must take prevalence
-# if datadir is not set, we're doing a build and LILYPOND_DATADIR
-
-datadir = '/usr/local/share/lilypond/2.10.33'
-if not os.path.isdir (datadir):
-    datadir = '/usr/local/share/lilypond/2.10.33'
-if os.environ.has_key ('LILYPOND_DATADIR') :
-    datadir = os.environ['LILYPOND_DATADIR']
-    while datadir[-1] == os.sep:
-	datadir= datadir[:-1]
-
-sys.path.insert (0, os.path.join (datadir, 'python'))
-
-
 
+# Python 2.5 only accepts strings with proper Python internal encoding
+# (i.e. ASCII or Unicode) when writing to stdout/stderr, so we must
+# use ugettext iso gettext, and encode the string when writing to
+# stdout/stderr
 
 localedir = '/usr/local/share/locale'
 try:
     import gettext
-    gettext.bindtextdomain ('lilypond', localedir)
-    gettext.textdomain ('lilypond')
-    _ = gettext.gettext
+    t = gettext.translation ('lilypond', localedir)
+    _ = t.ugettext
 except:
     def _ (s):
 	return s
 underscore = _
-progress = sys.stderr.write 
+
+# Urg, Python 2.4 does not define stderr/stdout encoding
+# Maybe guess encoding from LANG/LC_ALL/LC_CTYPE?
+
+def encoded_write(f, s):
+    f.write (s.encode (f.encoding or 'utf_8'))
+
+# ugh, Python 2.5 optparse requires Unicode strings in some argument
+# functions, and refuse them in some other places
+def display_encode (s):
+    return s.encode (sys.stderr.encoding or 'utf_8')
+
+def stderr_write (s):
+    encoded_write (sys.stderr, s)
+
+progress = stderr_write
+
+def require_python_version ():
+    if sys.hexversion < 0x02040000:
+        stderr_write ("Python 2.4 or newer is required to run this program.\n\
+Please upgrade Python from http://python.org/download/, and if you use MacOS X,\n\
+please read 'Setup for MacOS X' in Application Usage.")
+        os.system ("open http://python.org/download/")
+        sys.exit (2)
 
 # Modified version of the commands.mkarg(x), which always uses 
 # double quotes (since Windows can't handle the single quotes:
@@ -168,7 +174,7 @@ def strip_extension (f, ext):
 
 def search_exe_path (name):
     p = os.environ['PATH']
-    exe_paths = string.split (p, ':')
+    exe_paths = p.split (':')
     for e in exe_paths:
 	full = os.path.join (e, name)
 	if os.path.exists (full):
@@ -200,7 +206,7 @@ class NonDentedHeadingFormatter (optparse.IndentedHelpFormatter):
 			       metavar)
 
     def format_usage(self, usage):
-        return _("Usage: %s\n") % usage
+        return _("Usage: %s") % usage + '\n'
 
     def format_description(self, description):
 	return description
